summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameLayout.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kword/KWFrameLayout.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kword/KWFrameLayout.h')
-rw-r--r--kword/KWFrameLayout.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kword/KWFrameLayout.h b/kword/KWFrameLayout.h
index c4b3f7eb..18089ee5 100644
--- a/kword/KWFrameLayout.h
+++ b/kword/KWFrameLayout.h
@@ -68,7 +68,7 @@ public:
// frame number for the given page.... -1 if no frame on that page
// The first frame is number 0.
int frameNumberForPage( int page ) const;
// The last frame we need (0-based), layout() will delete any frame after that
int lastFrameNumber( int lastPage ) const;
void debug();
@@ -89,14 +89,14 @@ public:
enum { DontRemovePages = 1 };
/**
* The main method of this file. Do the frame layout.
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
* @param fromPage first page to layout ( 0-based )
* @param toPage last page to layout ( 0-based )
* @param flags see enum above
*/
- void layout( KWFrameSet* mainTextFrameSet, int numColumns,
+ void tqlayout( KWFrameSet* mainTextFrameSet, int numColumns,
int fromPage, int toPage, uint flags );
protected:
@@ -68,7 +68,7 @@ public:
// The first frame is number 0.
int frameNumberForPage( int page ) const;
- // The last frame we need (0-based), layout() will delete any frame after that
+ // The last frame we need (0-based), tqlayout() will delete any frame after that
int lastFrameNumber( int lastPage ) const;
void debug();
@@ -89,14 +89,14 @@ public:
enum { DontRemovePages = 1 };
/**
- * The main method of this file. Do the frame layout.
+ * The main method of this file. Do the frame tqlayout.
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
@@ -89,14 +89,14 @@ public:
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
- * @param fromPage first page to layout ( 0-based )
- * @param toPage last page to layout ( 0-based )
+ * @param fromPage first page to tqlayout ( 0-based )
+ * @param toPage last page to tqlayout ( 0-based )
* @param flags see enum above
*/